/*
* ============================================================================
*  Name        : mmccexengineobserver.h
*  Part of     : mccexample / mccexengine
*  Description : MMccExEngineObserver declaration
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef M_MMCCEXENGINEOBSERVER_H
#define M_MMCCEXENGINEOBSERVER_H

#include <e32std.h>

#include "tcontrolstate.h"


/**
 * MMccExEngineObserver defines an interface for observing different events
 * coming from the MCC example engine. These events are usually related to
 * various setup activities and state changes.
 * 
 * @see CMccExEngine
 */
class MMccExEngineObserver
    {
public:
    
    /**
     * Notification that network connection setup has started.
     */
    virtual void NetworkSetupStarted() = 0;
    
    /**
     * Network connection setup ready notification. This function is called
     * when the network connection setup has completed.
     * 
     * @param aError Symbian OS error code associated with the connection
     *               setup. If conenction setup was successful
     *               aError == KErrNone.
     */
    virtual void NetworkSetupReady( TInt aError ) = 0;
    
    /**
     * State change complete notification. This function is called when the
     * state change has completed.
     * 
     * @param aState New state in which the transition resulted.
     * @param aError Standard Symbian OS error code associated with the state
     *               change. If state change was successful
     *               aError == KErrNone.
     */
    virtual void StateChangeComplete( TControlState aState, TInt aError ) = 0;
    
    /**
     * Error detection notification. This function is called when an error is
     * detected during some state. These errors can be e.g. ICMP errors from
     * a poor network connection etc.
     * 
     * @param aState State in which the error was detected.
     * @param aError Error code of the error - standard Symbian OS error code.
     */
    virtual void ErrorDetected( TControlState aState, TInt aError ) = 0;
    
    };

#endif  // M_MMCCEXENGINEOBSERVER_H
