/*
* ============================================================================
*  Name        : tcontrolstate.h
*  Part of     : mccexample / mccexapp
*  Description : TControlState declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef TCONTROLSTATE_H
#define TCONTROLSTATE_H

#include <e32std.h>

/**
 * Enumeration of possible states of the control. Allowed state changes are as
 * follows:
 * 
 * Start state: any, end state: EStateStopped
 * Start state: EStateStopped, end state: EStatePrepared
 * Start state: EStatePrepared, end state: EStateStarted
 * Start state: EStateStarted, end state: EStatePaused
 * Start state: EStatePaused, end state: EStateStarted
 * 
 * Thus EStateStopped is considered as the basic state of the control.
 * Control must always be prepared before it is started and state changes
 * between EStateStarted and EStatePaused are allowed.
 * 
 * Control can be reset from any state to its idle state which as said is
 * EStateStopped.
 * 
 * Note that some control operations which do not affect state may require
 * that the control is in some state in order to execute the operation
 * successfully.
 * 
 * EStateChanging is used to indicate that a state change operation is
 * currently in progress and the actual state cannot be determined before
 * that change has finished.
 * 
 */
enum TControlState
    {
    EStateStopped   = 0,
    EStatePrepared  = 1,
    EStateStarted   = 2,
    EStatePaused    = 3,
    EStateChanging  = 1000
    };

#endif  // TCONTROLSTATE_H
