/*
* ============================================================================
*  Name        : mccexbasecontrol.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppBaseControl declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPBASECONTROL_H
#define C_CMCCEXAPPBASECONTROL_H

#include <coecntrl.h>

class CAknsBasicBackgroundControlContext;

/**
 * MCC example application base control. All MCC example application controls
 * or compound controls derive from this class. 
 * 
 * Main functionality provided by this class for derived classes is proper
 * background drawing which takes used skin into account.
 */
class CMccExAppBaseControl : public CCoeControl
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CMccExAppBaseControl();

// from CCoeControl
    
    /**
     * From CCoeControl.
     * Handles resource changes for this container - namely layout related.
     * 
     * @see CCoeControl
     */
    virtual void HandleResourceChange( TInt aType );
    
    /**
     * From CCoeControl.
     * Draw this CMccExAppBaseControl to the screen.
     * 
     * @see CCoeControl
     * @param aRect the rectangle of this view that needs updating.
     */
    virtual void Draw( const TRect& aRect ) const;
    
    /**
     * From CCoeControl.
     * Called by framework when the view size is changed.
     * 
     * @see CCoeControl
     */
    virtual void SizeChanged();
    
    /**
     * From MObjectProvider.
     * Retrieves an object of the same type as that encapsulated in aId.
     * 
     * @see CCoeControl
     * @see MObjectProvider
     */
    virtual TTypeUid::Ptr MopSupplyObject( TTypeUid aId );

protected:
    
    /**
     * 2nd phase constructor. Basically calls CreateWindowAndBackgroundL and
     * SetRectAndActivateL.
     * 
     * @param aRect The rectangle this container uses.
     */
    void BaseConstructL( const TRect& aRect );
    
    /**
     * Helper function for background and window creation. Provides more fine
     * grained control when constructing this object.
     * 
     * @param aRect The rectangle this container uses.
     */
    void CreateWindowAndBackgroundL( const TRect& aRect );
    
    /**
     * Helper function for activation and rect setting. Provides more fine
     * grained control when constructing this object.
     * 
     * @param aRect The rectangle this container uses.
     */
    void SetRectAndActivateL( const TRect& aRect );
    
    /**
     * C++ default constructor.
     */
    CMccExAppBaseControl();
    
private:    // Data
    
    /**
     * Background context for skins.
     * Own.
     */
    CAknsBasicBackgroundControlContext* iBgContext;
    
    };

#endif // C_CMCCEXAPPBASECONTROL_H
