/*
* ============================================================================
*  Name        : mccexappcodecsettingview.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppCodecSettingView declaration
*  Version     : %version: %
*
*  Copyright  2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPCODECSETTINGVIEW_H
#define C_CMCCEXAPPCODECSETTINGVIEW_H

#include "mccexappviewbase.h"

class CMccExAppCodecSettingList;
class CMccExAppCodecSettings;
class CMccExEngine;

/**
 * Class CMccExAppCodecSettingView is used for codec settings editing.
 */
class CMccExAppCodecSettingView : public CMccExAppViewBase
    {
public:
    
// Constructors and destructor
    
    /**
     * Two-phased constructor.
     * 
     * @return Pointer to a CMccExAppCodecSettingView object.
     */
    static CMccExAppCodecSettingView* NewL( CMccExEngine& aEngine );
    
    /**
     * Two-phased constructor. Leaves the object into cleanup stack.
     * 
     * @return Pointer to a CMccExAppCodecSettingView object.
     */
    static CMccExAppCodecSettingView* NewLC( CMccExEngine& aEngine );
    
    /**
     * Destructor.
     */
    virtual ~CMccExAppCodecSettingView();
    
// from CAknView
    
    /**
     * From CAknView.
     * View specific command handling.
     * 
     * @see CAknView.
     * @param aCommand ID of the command.
     */
    void HandleCommandL( TInt aCommand );
    
protected:
    
// From CMccExAppViewBase
    
    /**
     * From CMccExAppViewBase.
     * Factory function for creating the compound control.
     * 
     * @see CMccExAppViewBase.
     * @return Compound control.
     */
    CCoeControl* CreateContainerL();
    
private:
    
    /**
     * C++ default constructor.
     */
    CMccExAppCodecSettingView( CMccExEngine& aEngine );
    
    /**
     * Symbian 2nd phase constructor.
     */
    void ConstructL();
    
// New functions
    
    /**
     * Helper function for changing a single setting item.
     */
    void DoChangeSettingItemL();
    
    /**
     * Helper function saving the settings.
     */
    void DoSaveSettingsL();
    
private:    // Data
    
    /**
     * Codec settings model.
     * Own.
     */
    CMccExAppCodecSettings* iSettings;
    
    };

#endif // C_CMCCEXAPPCODECSETTINGVIEW_H
