/*
* ============================================================================
*  Name        : mccexappvideocontainer.h
*  Part of     : mccexample / mccexapp
*  Description : CMccExAppVideoContainer declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXAPPVIDEOCONTAINER_H
#define C_CMCCEXAPPVIDEOCONTAINER_H

#include "mccexappbasecontrol.h"

class MVideoControl;
class TVideoDeviceParameters;

/**
 * MCC example application video container control.
 */
class CMccExAppVideoContainer : public CMccExAppBaseControl
    {
public:

    /**
     * Two-phased constructor. Create a CMccExAppVideoContainer object, which
     * will draw itself to aRect.
     * 
     * @param aRect The rectangle this view will be drawn to.
     * @return A pointer to the created instance of CMccExAppVideoContainer.
     */
    static CMccExAppVideoContainer* NewL( const TRect& aRect );

    /**
     * Two-phased constructor. Leaves created object in cleanup stack. Create
     * a CMccExAppVideoContainer object, which will draw itself to aRect.
     * 
     * @param aRect Rectangle this view will be drawn to.
     * @return A pointer to the created instance of CMccExAppVideoContainer.
     */
    static CMccExAppVideoContainer* NewLC( const TRect& aRect );

    /**
     * Destructor.
     */
    virtual ~CMccExAppVideoContainer();
    
    /**
     * Sets the video control associated to this container. This function will
     * panic if the given parameter is NULL.
     * 
     * @param aControl Pointer to the video control.
     */
    void SetVideoControl( MVideoControl* aControl );
    
    /**
     * Sets the video device parameters used in video control creation.
     * 
     * @param aParams Upon return will contain the needed parameters used in
     *                video control creation.
     */
    void CreateVideoParametersL( TVideoDeviceParameters& aParams );
    
// from CMccExAppBaseControl
    
    /**
     * From CMccExAppBaseControl.
     * Draw this CMccExAppMainContainer to the screen.
     * 
     * @see CMccExAppBaseControl
     * @param aRect the rectangle of this view that needs updating.
     */
    void Draw( const TRect& aRect ) const;
    
    /**
     * From CMccExAppBaseControl.
     * Handles resource changes for this container - namely layout related.
     * 
     * @see CCoeControl
     */
    void HandleResourceChange( TInt aType );

private:

    /**
     * C++ default constructor.
     */
    CMccExAppVideoContainer();
    
private:    // Data
    
    /**
     * Pointer to the video control.
     * 
     * Not own.
     */
    MVideoControl* iVideoControl;
    
    };

#endif // C_CMCCEXAPPVIDEOCONTAINER_H
