/*
* ============================================================================
*  Name        : mccexenginecamerainfo.h
*  Part of     : mccexample / mccexengine
*  Description : CMccExEngineCameraInfo declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CMCCEXENGINECAMERAINFO_H
#define C_CMCCEXENGINECAMERAINFO_H

#include <e32base.h>
#include <ecam.h>

/**
 * CMccExEngineCameraInfo provides various camera related information to be
 * used with video streams.
 */
NONSHARABLE_CLASS( CMccExEngineCameraInfo ) : public CBase,
    public MCameraObserver2
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CMccExEngineCameraInfo();

    /**
     * Two-phased constructor.
     */
    static CMccExEngineCameraInfo* NewL( TInt aCamIndex );

    /**
     * Two-phased constructor.
     */
    static CMccExEngineCameraInfo* NewLC( TInt aCamIndex );
    
    /**
     * Returns the number of cameras supported and available.
     * 
     * @return TInt Number of cameras.
     */
    static TInt CamerasAvailable();
    
    /**
     * Returns the video frame sizes available.
     * 
     * @param aSizes Array of video sizes. This array will contain the
     *               supported video frame sizes upon return.
     */
    void VideoFrameSizesL( RArray<TSize>& aSizes );
    
    /**
     * Gets the camera information for this camera.
     * 
     * @param aInfo Will contain the camera information upon return.
     */
    void CameraInformation( TCameraInfo& aInfo );
    
// From MCameraObserver2
    
    /**
     * From MCameraObserver2.
     * Camera event handling function.
     * 
     * @see MCameraObserver2::HandleEvent
     */
    void HandleEvent( const TECAMEvent& aEvent );
    
    /**
     * From MCameraObserver2.
     * Viewfinder is ready.
     * 
     * @see MCameraObserver2::ViewFinderReady
     */
    void ViewFinderReady( MCameraBuffer& aCameraBuffer, TInt aError );
    
    /**
     * From MCameraObserver2.
     * Imagebuffer is ready.
     * 
     * @see MCameraObserver2::ImageBufferReady
     */
    void ImageBufferReady( MCameraBuffer& aCameraBuffer, TInt aError );
    
    /**
     * From MCameraObserver2.
     * Videobuffer is ready.
     * 
     * @see MCameraObserver2::VideoBufferReady
     */
    void VideoBufferReady( MCameraBuffer& aCameraBuffer, TInt aError );
    
private:
    
    /**
     * Constructor for performing 1st stage construction.
     */
    CMccExEngineCameraInfo( TInt aCamIndex );
    
    /**
     * 2nd phase Symbian constructor.
     */
    void ConstructL();
    
private:    // Data
    
    /**
     * Camera instance.
     * Own
     */
    CCamera* iCamera;
    
    /**
     * Index of the camera.
     */
    TInt iCameraIndex;
    
    };

#endif  // C_CMCCEXENGINECAMERAINFO_H
