/*
* ============================================================================
*  Name        : uplinkvideostream.h
*  Part of     : mccexample / mccexengine
*  Description : CUplinkVideoStream declaration
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.2
*/

#ifndef C_CUPLINKVIDEOSTREAM_H
#define C_CUPLINKVIDEOSTREAM_H

#include <e32base.h>

#include "videostreambase.h"

class CMccInterface;
class CMccCodecInformation;
class CStreamStateMachine;

/**
 * CUplinkVideoStream provides an implementation of uplink direction video
 * stream. In short this class can be used to create and control a video
 * stream from video input device (i.e. camera(s)) to IP network.
 */
NONSHARABLE_CLASS( CUplinkVideoStream ) : public CVideoStreamBase
    {
public:
    
    /**
     * Destructor.
     */
    virtual ~CUplinkVideoStream();

    /**
     * Two-phased constructor.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aCodec Reference to a codec which should be used for video.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     * @param aSize Video capture resolution.
     * @param aCameraIndex Index of the camera to be used.
     */
    static CUplinkVideoStream* NewL( CStreamStateMachine& aStateMachine,
            CMccCodecInformation& aCodec, CMccInterface& aMcc, 
            TUint32 aSession, TUint32 aLink,
            const TSize& aSize, TInt aCameraIndex );

    /**
     * Two-phased constructor. Leaves the created instance into the cleanup
     * stack.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aCodec Reference to a codec which should be used for video.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     * @param aSize Video capture resolution.
     * @param aCameraIndex Index of the camera to be used.
     */
    static CUplinkVideoStream* NewLC( CStreamStateMachine& aStateMachine,
            CMccCodecInformation& aCodec, CMccInterface& aMcc,
            TUint32 aSession, TUint32 aLink,
            const TSize& aSize, TInt aCameraIndex );
    
protected:
    
// From CStreamBase
    
    /**
     * From CStreamBase.
     * Finalizes the stream creation.
     * 
     * @see CStreamBase
     */
    void CreateStreamL();
    
private:
    
    /**
     * Constructor for performing 1st stage construction.
     * 
     * @param aStateMachine Reference to the state machine.
     * @param aMcc Reference to the MCC.
     * @param aSession ID of the session.
     * @param aLink ID of the link.
     * @param aSize Video capture resolution.
     * @param aCameraIndex Index of the camera to be used.
     */
    CUplinkVideoStream( CStreamStateMachine& aStateMachine,
            CMccInterface& aMcc, TUint32 aSession, TUint32 aLink,
            const TSize& aSize, TInt aCameraIndex );

private:    // Data
    
    /**
     * Index of the used camera.
     */
    TInt iCameraIndex;
    
    /**
     * Video size.
     */
    TSize iSize;
    
    };

#endif  // C_CUPLINKVIDEOSTREAM_H
