/*
* ============================================================================
*  Name        : downlinkaudiostream.cpp
*  Part of     : mccexample / mccexengine
*  Description : CDownlinkAudioStream class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccinterfacedef.h>
#include <mmccinterface.h>

#include "downlinkaudiostream.h"

// ======== MEMBER FUNCTIONS ========

// ---------------------------------------------------------------------------
// CDownlinkAudioStream::CDownlinkAudioStream
// ---------------------------------------------------------------------------
//
CDownlinkAudioStream::CDownlinkAudioStream(
    CStreamStateMachine& aStateMachine, CMccInterface& aMcc,
    TUint32 aSession, TUint32 aLink ) :
    CAudioStreamBase( aStateMachine, aMcc, aSession, aLink )
    {
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::~CDownlinkAudioStream
// ---------------------------------------------------------------------------
//
CDownlinkAudioStream::~CDownlinkAudioStream()
    {
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::NewLC
// ---------------------------------------------------------------------------
//
CDownlinkAudioStream* CDownlinkAudioStream::NewLC(
    CStreamStateMachine& aStateMachine,
    CMccCodecInformation& aCodec,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink )
    {
    CDownlinkAudioStream* self = new ( ELeave ) CDownlinkAudioStream( 
            aStateMachine, aMcc, aSession, aLink );
    CleanupStack::PushL( self );
    self->ConstructL( aCodec, KMccAudioDownlinkStream );
    return self;
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::NewL
// ---------------------------------------------------------------------------
//
CDownlinkAudioStream* CDownlinkAudioStream::NewL(
    CStreamStateMachine& aStateMachine,
    CMccCodecInformation& aCodec,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink )
    {
    CDownlinkAudioStream* self = CDownlinkAudioStream::NewLC( aStateMachine, 
            aCodec, aMcc, aSession, aLink );
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::CurrentAudioRouteL
// ---------------------------------------------------------------------------
//
TUint32 CDownlinkAudioStream::CurrentAudioRouteL()
    {
    TUint32 result( KMaxTUint32 );
    TPckgBuf<TUint32> buffer( result );
    
    User::LeaveIfError(
            MccInterface().GetParameter(
                    SessionId(), LinkId(), StreamId(), SinkEndpointId(),
                    KMccSpeakerRouting, buffer ) );
    
    result = buffer();
    return result;
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::SetCurrentAudioRouteL
// ---------------------------------------------------------------------------
//
void CDownlinkAudioStream::SetCurrentAudioRouteL( TUint32 aRoute )
    {
    TPckgC<TUint32> buffer( aRoute );
    User::LeaveIfError(
            MccInterface().SetParameter(
                    SessionId(), LinkId(), StreamId(), SinkEndpointId(),
                    KMccSpeakerRouting, buffer ) );
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::VolumeL
// ---------------------------------------------------------------------------
//
TInt CDownlinkAudioStream::VolumeL()
    {
    TInt result( 0 );
    TPckgBuf<TInt> buffer( result );
    User::LeaveIfError(
            MccInterface().GetParameter(
                    SessionId(), LinkId(), StreamId(), SinkEndpointId(),
                    KMccSpeakerVolume, buffer ) );
    
    result = buffer();
    return result;
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::SetVolumeL
// ---------------------------------------------------------------------------
//
void CDownlinkAudioStream::SetVolumeL( TInt aVolume )
    {
    TPckgC<TInt> buffer( aVolume );
    User::LeaveIfError(
            MccInterface().SetParameter(
                    SessionId(), LinkId(), StreamId(), SinkEndpointId(),
                    KMccSpeakerVolume, buffer ) );
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::MaxVolumeL
// ---------------------------------------------------------------------------
//
TInt CDownlinkAudioStream::MaxVolumeL()
    {
    TInt result( 0 );
    TPckgBuf<TInt> buffer( result );
    User::LeaveIfError(
            MccInterface().GetParameter(
                    SessionId(), LinkId(), StreamId(), SinkEndpointId(),
                    KMccSpeakerMaxVolume, buffer ) );
    
    result = buffer();
    return result;
    }


// ---------------------------------------------------------------------------
// CDownlinkAudioStream::CreateStreamL
// ---------------------------------------------------------------------------
//
void CDownlinkAudioStream::CreateStreamL()
    {
    AddSinkL( KUidMmfAudioOutput, KNullDesC8 );
    AddSourceL( KUidMccRtpSource, KNullDesC8 );
    SetCodecPriorityAndPreference( KExampleAudioPriority,
        KExampleDownlinkPreference );
    
    CStreamBase::CreateStreamL();
    }
