/*
* ============================================================================
*  Name        : streamstateactive.cpp
*  Part of     : mccexample / mccexengine
*  Description : CStreamStateActive class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccevents.h>
#include <mmccinterface.h>
#include <e32debug.h>

#include "streambase.h"
#include "streamstateactive.h"
#include "mccexpanic.pan"

// ======== MEMBER FUNCTIONS ========


// ---------------------------------------------------------------------------
// CStreamStateActive::CStreamStateActive
// ---------------------------------------------------------------------------
//
CStreamStateActive::CStreamStateActive() : CStreamStateBase()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStateActive::~CStreamStateActive
// ---------------------------------------------------------------------------
//
CStreamStateActive::~CStreamStateActive()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStateActive::NewLC
// ---------------------------------------------------------------------------
//
CStreamStateActive* CStreamStateActive::NewLC()
    {
    CStreamStateActive* self = new ( ELeave ) CStreamStateActive();
    CleanupStack::PushL( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStateActive::NewL
// ---------------------------------------------------------------------------
//
CStreamStateActive* CStreamStateActive::NewL()
    {
    CStreamStateActive* self = CStreamStateActive::NewLC();
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStateActive::ControlState
// ---------------------------------------------------------------------------
//
TControlState CStreamStateActive::ControlState() const
    {
    return EStateStarted;
    }


// ---------------------------------------------------------------------------
// CStreamStateActive::HandleMccEvent
// ---------------------------------------------------------------------------
//
void CStreamStateActive::HandleMccEvent( const TMccEvent& aEvent,
    CStreamBase& aStream )
    {
    RDebug::Print( _L( "CStreamStateActive got eventtype: %u" ),
            aEvent.iEventType );
    
    switch( aEvent.iEventType )
        {
        case KMccStreamStarted:
        case KMccStreamResumed:
            CStreamStateBase::HandleMccEvent( aEvent, aStream );
            break;
        // Next events are informative only
        case KMccActivityEvent:
        case KMccInactivityEvent:
        case KMccStreamIdle:
            break;
        default:
            MccExPanic( EMccExEventType );
            break;
        }
    }


// ---------------------------------------------------------------------------
// CStreamStateActive::DoEnterStateL
// ---------------------------------------------------------------------------
//
void CStreamStateActive::DoEnterStateL( CStreamBase& aStream,
    const CStreamStateBase& aPrevState )
    {
    // Assert that state transition obeys the rules.
    __ASSERT_ALWAYS( EStatePaused == aPrevState.ControlState() ||
                     EStatePrepared == aPrevState.ControlState(),
                     User::Leave( KErrArgument ) );
    
    const TUint32 session( aStream.SessionId() );
    const TUint32 link( aStream.LinkId() );
    const TUint32 stream( aStream.StreamId() );
    const TBool rtcp( aStream.RtcpUsage() );
    
    if ( EStatePaused == aPrevState.ControlState() )
        {
        User::LeaveIfError( aStream.MccInterface().ResumeStream(
                session, link, stream, 0, rtcp ) );
        }
    else
        {
        User::LeaveIfError( aStream.MccInterface().StartStream(
                session, link, stream, 0, EFalse, rtcp ) );
        }
    }
