/*
* ============================================================================
*  Name        : streamstatemachine.cpp
*  Part of     : mccexample / mccexengine
*  Description : CStreamStateMachine implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include "streamstatemachine.h"
#include "streamstatestopped.h"
#include "streamstateprepared.h"
#include "streamstateactive.h"
#include "streamstatepaused.h"

// ======== MEMBER FUNCTIONS ========

// ---------------------------------------------------------------------------
// CStreamStateMachine::CStreamStateMachine
// ---------------------------------------------------------------------------
//
CStreamStateMachine::CStreamStateMachine()
    {
    }


// ---------------------------------------------------------------------------
// CStreamStateMachine::~CStreamStateMachine
// ---------------------------------------------------------------------------
//
CStreamStateMachine::~CStreamStateMachine()
    {
    // N.B: After ResetAndDestroy(), iStates can go out of scope so Close() is
    // not needed.
    iStates.ResetAndDestroy();
    }


// ---------------------------------------------------------------------------
// CStreamStateMachine::NewLC
// ---------------------------------------------------------------------------
//
CStreamStateMachine* CStreamStateMachine::NewLC()
    {
    CStreamStateMachine* self = new ( ELeave ) CStreamStateMachine();
    CleanupStack::PushL( self );
    self->ConstructL();
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStateMachine::NewL
// ---------------------------------------------------------------------------
//
CStreamStateMachine* CStreamStateMachine::NewL()
    {
    CStreamStateMachine* self = CStreamStateMachine::NewLC();
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CStreamStateMachine::ConstructL
// ---------------------------------------------------------------------------
//
void CStreamStateMachine::ConstructL()
    {
    CStreamStateBase* stopped = CStreamStateStopped::NewLC();
    iStates.AppendL( stopped );
    CleanupStack::Pop( stopped );
    
    CStreamStateBase* prepared = CStreamStatePrepared::NewLC();
    iStates.AppendL( prepared );
    CleanupStack::Pop( prepared );
    
    CStreamStateBase* active = CStreamStateActive::NewLC();
    iStates.AppendL( active );
    CleanupStack::Pop( active );
    
    CStreamStateBase* paused = CStreamStatePaused::NewLC();
    iStates.AppendL( paused );
    CleanupStack::Pop( paused );
    }


// ---------------------------------------------------------------------------
// CStreamStateMachine::RequestStateL
// ---------------------------------------------------------------------------
//
CStreamStateBase& CStreamStateMachine::RequestStateL(
    TControlState aRequested )
    {
    TInt idx = iStates.Count();
    CStreamStateBase* retState( NULL );
    while ( idx && !retState )
        {
        idx -= 1;
        if ( iStates[idx]->ControlState() == aRequested )
            {
            retState = iStates[idx];
            }
        }
    
    // Assert that the state was found - otherwise caller provided bad
    // arguments or we are in incorrect state.
    __ASSERT_ALWAYS( retState, User::Leave( KErrNotFound ) );
    return *retState;
    }
