/*
* ============================================================================
*  Name        : uplinkaudiostream.cpp
*  Part of     : mccexample / mccexengine
*  Description : CUplinkAudioStream class implementation
*  Version     : %version: %
*
*  Copyright  2008-2009 Nokia.  All rights reserved.
*  This material, including documentation and any related computer
*  programs, is protected by copyright controlled by Nokia.  All
*  rights are reserved.  Copying, including reproducing, storing,
*  adapting or translating, any or all of this material requires the
*  prior written consent of Nokia.  This material also contains
*  confidential information which may not be disclosed to others
*  without the prior written consent of Nokia.
* ============================================================================
* Template version: 4.1.1
*/

#include <mmccinterfacedef.h>
#include <mmccinterface.h>

#include "uplinkaudiostream.h"

// ======== MEMBER FUNCTIONS ========

// ---------------------------------------------------------------------------
// CUplinkAudioStream::CUplinkAudioStream
// ---------------------------------------------------------------------------
//
CUplinkAudioStream::CUplinkAudioStream( CStreamStateMachine& aStateMachine,
    CMccInterface& aMcc, TUint32 aSession, TUint32 aLink  ) : 
    CAudioStreamBase( aStateMachine, aMcc, aSession, aLink )
    {
    }


// ---------------------------------------------------------------------------
// CUplinkAudioStream::~CUplinkAudioStream
// ---------------------------------------------------------------------------
//
CUplinkAudioStream::~CUplinkAudioStream()
    {
    }


// ---------------------------------------------------------------------------
// CUplinkAudioStream::NewLC
// ---------------------------------------------------------------------------
//
CUplinkAudioStream* CUplinkAudioStream::NewLC(
    CStreamStateMachine& aStateMachine,
    CMccCodecInformation& aCodec,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink  )
    {
    CUplinkAudioStream* self = new ( ELeave ) CUplinkAudioStream( 
            aStateMachine, aMcc, aSession, aLink );
    CleanupStack::PushL( self );
    self->ConstructL( aCodec, KMccAudioUplinkStream );
    return self;
    }


// ---------------------------------------------------------------------------
// CUplinkAudioStream::NewL
// ---------------------------------------------------------------------------
//
CUplinkAudioStream* CUplinkAudioStream::NewL( 
    CStreamStateMachine& aStateMachine,
    CMccCodecInformation& aCodec,
    CMccInterface& aMcc,
    TUint32 aSession,
    TUint32 aLink )
    {
    CUplinkAudioStream* self = CUplinkAudioStream::NewLC( aStateMachine,
            aCodec, aMcc, aSession, aLink );
    CleanupStack::Pop( self );
    return self;
    }


// ---------------------------------------------------------------------------
// CUplinkAudioStream::SetMuteStateL
// ---------------------------------------------------------------------------
//
void CUplinkAudioStream::SetMuteStateL( TBool aMuteState )
    {
    TUint32 gain( 0 );
    if ( !aMuteState )
        {
        gain = 1;
        }
    
    TPckgC<TUint32> buffer( gain );
    User::LeaveIfError( MccInterface().SetParameter(
                        SessionId(), LinkId(), StreamId(), SourceEndpointId(),
                        KMccMicGain, buffer ) );
    }


// ---------------------------------------------------------------------------
// CUplinkAudioStream::CreateStreamL
// ---------------------------------------------------------------------------
//
void CUplinkAudioStream::CreateStreamL()
    {
    AddSinkL( KUidMccRtpSink, KNullDesC8 );
    AddSourceL( KUidMmfAudioInput, KNullDesC8 );
    SetCodecPriorityAndPreference( KExampleAudioPriority,
        KExampleUplinkPreference );
    
    CStreamBase::CreateStreamL();
    }
